@@ -1,4 +1,4 @@
-// Copyright (c) 2025 Proton AG
+// Copyright (c) 2026 Proton AG
 //
 // This file is part of Proton Mail Bridge.
 //
@@ -28,6 +28,7 @@ import (
 	"github.com/ProtonMail/gluon/async"
 	"github.com/ProtonMail/go-proton-api"
 	"github.com/ProtonMail/proton-bridge/v3/internal/service"
+	"github.com/google/uuid"
 	"github.com/sirupsen/logrus"
 )
 
@@ -37,14 +38,16 @@ var pollJitter = 2 * time.Minute  //nolint:gochecknoglobals
 const filename = "unleash_flags"
 
 const (
-	EventLoopNotificationDisabled                 = "InboxBridgeEventLoopNotificationDisabled"
-	IMAPAuthenticateCommandDisabled               = "InboxBridgeImapAuthenticateCommandDisabled"
-	UserRemovalGluonDataCleanupDisabled           = "InboxBridgeUserRemovalGluonDataCleanupDisabled"
-	UpdateUseNewVersionFileStructureDisabled      = "InboxBridgeUpdateWithOsFilterDisabled"
-	LabelConflictResolverDisabled                 = "InboxBridgeLabelConflictResolverDisabled"
-	SMTPSubmissionRequestSentryReportDisabled     = "InboxBridgeSmtpSubmissionRequestSentryReportDisabled"
-	InternalLabelConflictResolverDisabled         = "InboxBridgeUnexpectedFoldersLabelsStartupFixupDisabled"
-	ItnternalLabelConflictNonEmptyMailboxDeletion = "InboxBridgeUnknownNonEmptyMailboxDeletion"
+	EventLoopNotificationDisabled                        = "InboxBridgeEventLoopNotificationDisabled"
+	IMAPAuthenticateCommandDisabled                      = "InboxBridgeImapAuthenticateCommandDisabled"
+	UserRemovalGluonDataCleanupDisabled                  = "InboxBridgeUserRemovalGluonDataCleanupDisabled"
+	UpdateUseNewVersionFileStructureDisabled             = "InboxBridgeUpdateWithOsFilterDisabled"
+	LabelConflictResolverDisabled                        = "InboxBridgeLabelConflictResolverDisabled"
+	SMTPSubmissionRequestSentryReportDisabled            = "InboxBridgeSmtpSubmissionRequestSentryReportDisabled"
+	InternalLabelConflictResolverDisabled                = "InboxBridgeUnexpectedFoldersLabelsStartupFixupDisabled"
+	InternalLabelConflictNonEmptyMailboxDeletion         = "InboxBridgeUnknownNonEmptyMailboxDeletion"
+	LinuxVaultPreferredKeychainNotAvailableRetryDisabled = "InboxBridgeLinuxVaultPreferredKeychainNotAvailableRetryDisabled"
+	InboxBridgeU2FLoginEnabled                           = "InboxBridgeU2FLogin"
 )
 
 type FeatureFlagValueProvider interface {
@@ -83,7 +86,13 @@ type Service struct {
 	getFeaturesFn func(ctx context.Context) (proton.FeatureFlagResult, error)
 }
 
-func NewBridgeService(ctx context.Context, api *proton.Manager, locator service.Locator, panicHandler async.PanicHandler) *Service {
+func NewBridgeService(
+	ctx context.Context,
+	api *proton.Manager,
+	locator service.Locator,
+	panicHandler async.PanicHandler,
+	featureFlagUUID uuid.UUID,
+) *Service {
 	log := logrus.WithField("service", "unleash")
 	cacheDir, err := locator.ProvideUnleashCachePath()
 	if err != nil {
@@ -92,7 +101,7 @@ func NewBridgeService(ctx context.Context, api *proton.Manager, locator service.
 	cachePath := filepath.Clean(filepath.Join(cacheDir, filename))
 
 	return newService(ctx, func(ctx context.Context) (proton.FeatureFlagResult, error) {
-		return api.GetFeatures(ctx)
+		return api.GetFeatures(ctx, featureFlagUUID)
 	}, log, cachePath, panicHandler)
 }
 
